try:
    from vcCommand import * 
    import vcMatrix, vcVector
    import csv
except:
    print "Modules not found"

cmd = getCommand()
app = cmd.Application
sim = cmd.Simulation

def OnStart():
  global teach_context, robot_controller, main_routine, path, import_option, btn_click
  teach_context = app.CurrentContext
  active_robot = teach_context.ActiveRobot
  robot_controller = active_robot.findBehavioursByType(VC_ROBOTCONTROLLER)[0]
  if not robot_controller:
    print 'No robot controller found'
    return
  #Get the main routine
  active_routine = teach_context.ActiveRoutine
  prg = active_routine.Program
  main_routine = prg.MainRoutine
  main_routine.clear() 

  path = cmd.createProperty(VC_URI, 'Select CSV')
  import_option = cmd.createProperty(VC_STRING, 'Import as', VC_PROPERTY_STEP)
  import_option.StepValues = ['Coordinates' , 'JointValues']
  import_option.Value = 'Coordinates'
  btn_click = cmd.createProperty(VC_BUTTON, 'Import')
  executeInActionPanel()
  btn_click.OnChanged = ImportFromCSV


def addPosition(name, stat, e, f, g, h, i, j):
  global robot_controller, import_option

  positions = stat.Positions
  pos_frame = positions[0]
  pos_frame.Name = name
  if import_option.Value == 'Coordinates':
    x, y, z, rx, ry, rz = e, f, g, h, i, j
    mtx = vcMatrix.new()
    p = vcVector.new(x, y, z)
    wpr = vcVector.new(rx, ry, rz)
    mtx.P = p 
    mtx.WPR = wpr
    pos_frame.PositionInWorld = mtx
  else:
    target = robot_controller.createTarget()
    j1, j2, j3, j4, j5, j6 = e, f, g, h, i, j
    target.JointValues = [j1, j2, j3, j4, j5, j6]
    pos_frame.PositionInReference = target.Target
    pos_frame.setJoints(target.JointValues)


def ImportFromCSV(prop):
  '''
  Import from cvs file row format\n
  Name     Type Base Tool X(J1)  Y(J2) Z(J3) Rx(J4) Ry(J5) Rz(J6)\n
  TestPTP1  PTP   1    1  200    400   600   25     50     75 
  '''
  global teach_context, path, robot_controller, main_routine

  bases = robot_controller.Bases
  tools = robot_controller.Tools

  uri = path.Value[8:]
  with open(uri) as csv_file:
    next(csv_file) #Skip the first line
    csv_reader = csv.reader(csv_file, delimiter = ',')
    for row in csv_reader:
      statement_name = str(row[0])
      statement_type = row[1]
      base_number = int(row[2])
      tool_number = int(row[3])
      #e, f, g, h, i, j, are the row name in csv file
      e = float(row[4])
      f = float(row[5])
      g = float(row[6])
      h = float(row[7])
      i = float(row[8])
      j = float(row[9])
      if statement_type == 'PTP':
        statement = main_routine.addStatement(VC_STATEMENT_PTPMOTION)
        statement.Base = bases[base_number]
        statement.Tool = tools[tool_number]
        addPosition(statement_name, statement, e, f, g, h, i, j)
      if statement_type == 'LIN':
        statement = main_routine.addStatement(VC_STATEMENT_LINMOTION)
        statement.Base = bases[base_number]
        statement.Tool = tools[tool_number]
        addPosition(statement_name, statement, e, f, g, h, i, j)

def SimulationOnStartStop(sim, IsRunning):
  cmd.Enabled = True
  if IsRunning:
    cmd.Enabled = False
  else:
    cmd.Enabled = True

sim.OnStartStop = SimulationOnStartStop